from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DmrsCls:
	"""Dmrs commands group definition. 11 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dmrs", core, parent)

	@property
	def apIndex(self):
		"""apIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apIndex'):
			from .ApIndex import ApIndexCls
			self._apIndex = ApIndexCls(self._core, self._cmd_group)
		return self._apIndex

	@property
	def ctype(self):
		"""ctype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctype'):
			from .Ctype import CtypeCls
			self._ctype = CtypeCls(self._core, self._cmd_group)
		return self._ctype

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def nsid(self):
		"""nsid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsid'):
			from .Nsid import NsidCls
			self._nsid = NsidCls(self._core, self._cmd_group)
		return self._nsid

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def seqGen(self):
		"""seqGen commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_seqGen'):
			from .SeqGen import SeqGenCls
			self._seqGen = SeqGenCls(self._core, self._cmd_group)
		return self._seqGen

	@property
	def seqHopping(self):
		"""seqHopping commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_seqHopping'):
			from .SeqHopping import SeqHoppingCls
			self._seqHopping = SeqHoppingCls(self._core, self._cmd_group)
		return self._seqHopping

	@property
	def sltSymbols(self):
		"""sltSymbols commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sltSymbols'):
			from .SltSymbols import SltSymbolsCls
			self._sltSymbols = SltSymbolsCls(self._core, self._cmd_group)
		return self._sltSymbols

	@property
	def tapos(self):
		"""tapos commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tapos'):
			from .Tapos import TaposCls
			self._tapos = TaposCls(self._core, self._cmd_group)
		return self._tapos

	@property
	def apSelect(self):
		"""apSelect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apSelect'):
			from .ApSelect import ApSelectCls
			self._apSelect = ApSelectCls(self._core, self._cmd_group)
		return self._apSelect

	def clone(self) -> 'DmrsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DmrsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CchannelCls:
	"""Cchannel commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cchannel", core, parent)

	@property
	def revision(self):
		"""revision commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_revision'):
			from .Revision import RevisionCls
			self._revision = RevisionCls(self._core, self._cmd_group)
		return self._revision

	def get_ps_offset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:PSOFfset \n
		Snippet: value: int = driver.source.bb.evdo.anetwork.cchannel.get_ps_offset() \n
		Sets the offset (in slots) from the start of control channel cycle to the start of the synchronous message capsule that
		contains the Sync Message. \n
			:return: ps_offset: integer Range: 0 to 3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:PSOFfset?')
		return Conversions.str_to_int(response)

	def set_ps_offset(self, ps_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:PSOFfset \n
		Snippet: driver.source.bb.evdo.anetwork.cchannel.set_ps_offset(ps_offset = 1) \n
		Sets the offset (in slots) from the start of control channel cycle to the start of the synchronous message capsule that
		contains the Sync Message. \n
			:param ps_offset: integer Range: 0 to 3
		"""
		param = Conversions.decimal_value_to_str(ps_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:PSOFfset {param}')

	# noinspection PyTypeChecker
	def get_rate(self) -> enums.EvdoDataRate:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:RATE \n
		Snippet: value: enums.EvdoDataRate = driver.source.bb.evdo.anetwork.cchannel.get_rate() \n
		Sets the rate that the control channel messages are transmitted at. \n
			:return: rate: DR4K8| DR9K6| DR19K2| DR38K4| DR76K8| DR153K6| DR307K2| DR614K4| DR921K6| DR1228K8| DR1536K| DR1843K2| DR2457K6| DR3072K| DR460K8| DR768K| DR1075K2| DR2150K4| DR3686K4| DR4300K8| DR4915K2
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:RATE?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoDataRate)

	def set_rate(self, rate: enums.EvdoDataRate) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:RATE \n
		Snippet: driver.source.bb.evdo.anetwork.cchannel.set_rate(rate = enums.EvdoDataRate.DR1075K2) \n
		Sets the rate that the control channel messages are transmitted at. \n
			:param rate: DR4K8| DR9K6| DR19K2| DR38K4| DR76K8| DR153K6| DR307K2| DR614K4| DR921K6| DR1228K8| DR1536K| DR1843K2| DR2457K6| DR3072K| DR460K8| DR768K| DR1075K2| DR2150K4| DR3686K4| DR4300K8| DR4915K2
		"""
		param = Conversions.enum_scalar_to_str(rate, enums.EvdoDataRate)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:RATE {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:STATe \n
		Snippet: value: bool = driver.source.bb.evdo.anetwork.cchannel.get_state() \n
		Enables or disables the control channel messages. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:CCHannel:STATe \n
		Snippet: driver.source.bb.evdo.anetwork.cchannel.set_state(state = False) \n
		Enables or disables the control channel messages. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:CCHannel:STATe {param}')

	def clone(self) -> 'CchannelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CchannelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IpAddressCls:
	"""IpAddress commands group definition. 5 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ipAddress", core, parent)

	@property
	def subnet(self):
		"""subnet commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subnet'):
			from .Subnet import SubnetCls
			self._subnet = SubnetCls(self._core, self._cmd_group)
		return self._subnet

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.EthernetMode:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress:MODE \n
		Snippet: value: enums.EthernetMode = driver.source.bb.nr5G.hfb.ethernet.ipAddress.get_mode() \n
		No command help available \n
			:return: eth_mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EthernetMode)

	def set_mode(self, eth_mode: enums.EthernetMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress:MODE \n
		Snippet: driver.source.bb.nr5G.hfb.ethernet.ipAddress.set_mode(eth_mode = enums.EthernetMode.AUTO) \n
		No command help available \n
			:param eth_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(eth_mode, enums.EthernetMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress:MODE {param}')

	def get_port(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress:PORT \n
		Snippet: value: int = driver.source.bb.nr5G.hfb.ethernet.ipAddress.get_port() \n
		No command help available \n
			:return: eth_port: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress:PORT?')
		return Conversions.str_to_int(response)

	def set_port(self, eth_port: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress:PORT \n
		Snippet: driver.source.bb.nr5G.hfb.ethernet.ipAddress.set_port(eth_port = 1) \n
		No command help available \n
			:param eth_port: No help available
		"""
		param = Conversions.decimal_value_to_str(eth_port)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress:PORT {param}')

	# noinspection PyTypeChecker
	def get_protocol(self) -> enums.NetProtocol:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress:PROTocol \n
		Snippet: value: enums.NetProtocol = driver.source.bb.nr5G.hfb.ethernet.ipAddress.get_protocol() \n
		No command help available \n
			:return: eth_protocol: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress:PROTocol?')
		return Conversions.str_to_scalar_enum(response, enums.NetProtocol)

	def set_protocol(self, eth_protocol: enums.NetProtocol) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress:PROTocol \n
		Snippet: driver.source.bb.nr5G.hfb.ethernet.ipAddress.set_protocol(eth_protocol = enums.NetProtocol.TCP) \n
		No command help available \n
			:param eth_protocol: No help available
		"""
		param = Conversions.enum_scalar_to_str(eth_protocol, enums.NetProtocol)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress:PROTocol {param}')

	def get_value(self) -> bytes:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress \n
		Snippet: value: bytes = driver.source.bb.nr5G.hfb.ethernet.ipAddress.get_value() \n
		No command help available \n
			:return: nr_5_gethernet_ip_address: No help available
		"""
		response = self._core.io.query_bin_block('SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress?')
		return response

	def set_value(self, nr_5_gethernet_ip_address: bytes) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:HFB:ETHernet:IPADdress \n
		Snippet: driver.source.bb.nr5G.hfb.ethernet.ipAddress.set_value(nr_5_gethernet_ip_address = b'ABCDEFGH') \n
		No command help available \n
			:param nr_5_gethernet_ip_address: No help available
		"""
		self._core.io.write_bin_block('SOURce<HwInstance>:BB:NR5G:HFB:ETHernet:IPADdress ', nr_5_gethernet_ip_address)

	def clone(self) -> 'IpAddressCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IpAddressCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, freq_resp_rf_slsel: str, index=repcap.Index.Default) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt<CH>:SELect \n
		Snippet: driver.source.correction.fresponse.rf.user.slist.select.set(freq_resp_rf_slsel = 'abc', index = repcap.Index.Default) \n
		Selects an existing S-parameter file (*.s<n>p) from the default directory or from the specific directory.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param freq_resp_rf_slsel: string Filename incl. file extension or complete file path Use 'none' to unload a file.
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slist')
		"""
		param = Conversions.value_to_quoted_str(freq_resp_rf_slsel)
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt{index_cmd_val}:SELect {param}')

	def get(self, index=repcap.Index.Default) -> str:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt<CH>:SELect \n
		Snippet: value: str = driver.source.correction.fresponse.rf.user.slist.select.get(index = repcap.Index.Default) \n
		Selects an existing S-parameter file (*.s<n>p) from the default directory or from the specific directory.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slist')
			:return: freq_resp_rf_slsel: string Filename incl. file extension or complete file path Use 'none' to unload a file."""
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		response = self._core.io.query_str(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt{index_cmd_val}:SELect?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AmCls:
	"""Am commands group definition. 7 total commands, 4 Subgroups, 2 group commands
	Repeated Capability: GeneratorIx, default value after init: GeneratorIx.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("am", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_generatorIx_get', 'repcap_generatorIx_set', repcap.GeneratorIx.Nr1)

	def repcap_generatorIx_set(self, generatorIx: repcap.GeneratorIx) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to GeneratorIx.Default
		Default value after init: GeneratorIx.Nr1"""
		self._cmd_group.set_repcap_enum_value(generatorIx)

	def repcap_generatorIx_get(self) -> repcap.GeneratorIx:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def depth(self):
		"""depth commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_depth'):
			from .Depth import DepthCls
			self._depth = DepthCls(self._core, self._cmd_group)
		return self._depth

	@property
	def deviation(self):
		"""deviation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_deviation'):
			from .Deviation import DeviationCls
			self._deviation = DeviationCls(self._core, self._cmd_group)
		return self._deviation

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def get_ratio(self) -> float:
		"""SCPI: [SOURce<HW>]:AM:RATio \n
		Snippet: value: float = driver.source.am.get_ratio() \n
		Sets the deviation ratio (path#2 to path#1) in percent. \n
			:return: ratio: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AM:RATio?')
		return Conversions.str_to_float(response)

	def set_ratio(self, ratio: float) -> None:
		"""SCPI: [SOURce<HW>]:AM:RATio \n
		Snippet: driver.source.am.set_ratio(ratio = 1.0) \n
		Sets the deviation ratio (path#2 to path#1) in percent. \n
			:param ratio: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(ratio)
		self._core.io.write(f'SOURce<HwInstance>:AM:RATio {param}')

	def get_sensitivity(self) -> float:
		"""SCPI: [SOURce<HW>]:AM:SENSitivity \n
		Snippet: value: float = driver.source.am.get_sensitivity() \n
		Sets the sensitivity of the external signal source for amplitude modulation in %/V. \n
			:return: sensitivity: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AM:SENSitivity?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'AmCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AmCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, carrier_index: int, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:MCCW:CARRier:STATe \n
		Snippet: driver.source.bb.mccw.carrier.state.set(carrier_index = 1, state = False) \n
		Switches the selected carrier on or off. \n
			:param carrier_index: integer Range: 0 to lastCarrier
			:param state: 1| ON| 0| OFF
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('carrier_index', carrier_index, DataType.Integer), ArgSingle('state', state, DataType.Boolean))
		self._core.io.write(f'SOURce<HwInstance>:BB:MCCW:CARRier:STATe {param}'.rstrip())

	# noinspection PyTypeChecker
	class StateStruct(StructBase):
		"""Response structure. Fields: \n
			- Carrier_Index: int: integer Range: 0 to lastCarrier
			- State: bool: 1| ON| 0| OFF"""
		__meta_args_list = [
			ArgStruct.scalar_int('Carrier_Index'),
			ArgStruct.scalar_bool('State')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Carrier_Index: int = None
			self.State: bool = None

	def get(self) -> StateStruct:
		"""SCPI: [SOURce<HW>]:BB:MCCW:CARRier:STATe \n
		Snippet: value: StateStruct = driver.source.bb.mccw.carrier.state.get() \n
		Switches the selected carrier on or off. \n
			:return: structure: for return value, see the help for StateStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:MCCW:CARRier:STATe?', self.__class__.StateStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 5 total commands, 2 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	@property
	def listPy(self):
		"""listPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def range(self):
		"""range commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_range'):
			from .Range import RangeCls
			self._range = RangeCls(self._core, self._cmd_group)
		return self._range

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.RfPortValType:
		"""SCPI: SCONfiguration:RFALignment:SETup:INFO:CALibration:FREQuency:MODE \n
		Snippet: value: enums.RfPortValType = driver.sconfiguration.rfAlignment.setup.info.calibration.frequency.get_mode() \n
		Queries the method used to be defined the calibrated frequency and PEP ranges. \n
			:return: mode: RANGe| LIST RANGe Range, see: method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Frequency.Range.lower method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Frequency.Range.upper method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Frequency.step method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Power.Range.lower method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Power.Range.upper method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Power.step LIST List, see: method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Frequency.ListPy.values method RsSmw.Sconfiguration.RfAlignment.Setup.Info.Calibration.Power.ListPy.values
		"""
		response = self._core.io.query_str('SCONfiguration:RFALignment:SETup:INFO:CALibration:FREQuency:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.RfPortValType)

	def get_step(self) -> float:
		"""SCPI: SCONfiguration:RFALignment:SETup:INFO:CALibration:FREQuency:STEP \n
		Snippet: value: float = driver.sconfiguration.rfAlignment.setup.info.calibration.frequency.get_step() \n
		Queries the frequency/PEP step size with that the calibration values are selected from the defined value range. \n
			:return: frequency_step: float
		"""
		response = self._core.io.query_str('SCONfiguration:RFALignment:SETup:INFO:CALibration:FREQuency:STEP?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'FrequencyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrequencyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SsAttenuationCls:
	"""SsAttenuation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ssAttenuation", core, parent)

	def set(self, ss_attenuation: enums.AntennaNr, testMode=repcap.TestMode.Default, slot=repcap.Slot.Default, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SCONfiguration:TMODe<DI>:SLOT<ST>:LDIRection<CH>:SSATtenuation \n
		Snippet: driver.source.bb.tetra.sconfiguration.tmode.slot.ldirection.ssAttenuation.set(ss_attenuation = enums.AntennaNr.A1, testMode = repcap.TestMode.Default, slot = repcap.Slot.Default, channel = repcap.Channel.Default) \n
		Sets the attenuation for the second sub-slot in a control burst. \n
			:param ss_attenuation: A1| A2| A3| A4
			:param testMode: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tmode')
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slot')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ldirection')
		"""
		param = Conversions.enum_scalar_to_str(ss_attenuation, enums.AntennaNr)
		testMode_cmd_val = self._cmd_group.get_repcap_cmd_value(testMode, repcap.TestMode)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:SCONfiguration:TMODe{testMode_cmd_val}:SLOT{slot_cmd_val}:LDIRection{channel_cmd_val}:SSATtenuation {param}')

	# noinspection PyTypeChecker
	def get(self, testMode=repcap.TestMode.Default, slot=repcap.Slot.Default, channel=repcap.Channel.Default) -> enums.AntennaNr:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SCONfiguration:TMODe<DI>:SLOT<ST>:LDIRection<CH>:SSATtenuation \n
		Snippet: value: enums.AntennaNr = driver.source.bb.tetra.sconfiguration.tmode.slot.ldirection.ssAttenuation.get(testMode = repcap.TestMode.Default, slot = repcap.Slot.Default, channel = repcap.Channel.Default) \n
		Sets the attenuation for the second sub-slot in a control burst. \n
			:param testMode: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tmode')
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slot')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ldirection')
			:return: ss_attenuation: A1| A2| A3| A4"""
		testMode_cmd_val = self._cmd_group.get_repcap_cmd_value(testMode, repcap.TestMode)
		slot_cmd_val = self._cmd_group.get_repcap_cmd_value(slot, repcap.Slot)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TETRa:SCONfiguration:TMODe{testMode_cmd_val}:SLOT{slot_cmd_val}:LDIRection{channel_cmd_val}:SSATtenuation?')
		return Conversions.str_to_scalar_enum(response, enums.AntennaNr)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CellCls:
	"""Cell commands group definition. 16 total commands, 9 Subgroups, 0 group commands
	Repeated Capability: CellNull, default value after init: CellNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cell", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_cellNull_get', 'repcap_cellNull_set', repcap.CellNull.Nr0)

	def repcap_cellNull_set(self, cellNull: repcap.CellNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to CellNull.Default
		Default value after init: CellNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(cellNull)

	def repcap_cellNull_get(self) -> repcap.CellNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def cdState(self):
		"""cdState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdState'):
			from .CdState import CdStateCls
			self._cdState = CdStateCls(self._core, self._cmd_group)
		return self._cdState

	@property
	def csirs(self):
		"""csirs commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_csirs'):
			from .Csirs import CsirsCls
			self._csirs = CsirsCls(self._core, self._cmd_group)
		return self._csirs

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import DurationCls
			self._duration = DurationCls(self._core, self._cmd_group)
		return self._duration

	@property
	def nzpNum(self):
		"""nzpNum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nzpNum'):
			from .NzpNum import NzpNumCls
			self._nzpNum = NzpNumCls(self._core, self._cmd_group)
		return self._nzpNum

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def periodicity(self):
		"""periodicity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_periodicity'):
			from .Periodicity import PeriodicityCls
			self._periodicity = PeriodicityCls(self._core, self._cmd_group)
		return self._periodicity

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def zpNum(self):
		"""zpNum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zpNum'):
			from .ZpNum import ZpNumCls
			self._zpNum = ZpNumCls(self._core, self._cmd_group)
		return self._zpNum

	def clone(self) -> 'CellCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CellCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PmchCls:
	"""Pmch commands group definition. 10 total commands, 10 Subgroups, 0 group commands
	Repeated Capability: IndexNull, default value after init: IndexNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pmch", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_indexNull_get', 'repcap_indexNull_set', repcap.IndexNull.Nr0)

	def repcap_indexNull_set(self, indexNull: repcap.IndexNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to IndexNull.Default
		Default value after init: IndexNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(indexNull)

	def repcap_indexNull_get(self) -> repcap.IndexNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def dlist(self):
		"""dlist commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlist'):
			from .Dlist import DlistCls
			self._dlist = DlistCls(self._core, self._cmd_group)
		return self._dlist

	@property
	def mcs(self):
		"""mcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs'):
			from .Mcs import McsCls
			self._mcs = McsCls(self._core, self._cmd_group)
		return self._mcs

	@property
	def mcsTwo(self):
		"""mcsTwo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcsTwo'):
			from .McsTwo import McsTwoCls
			self._mcsTwo = McsTwoCls(self._core, self._cmd_group)
		return self._mcsTwo

	@property
	def mod(self):
		"""mod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mod'):
			from .Mod import ModCls
			self._mod = ModCls(self._core, self._cmd_group)
		return self._mod

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def saEnd(self):
		"""saEnd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_saEnd'):
			from .SaEnd import SaEndCls
			self._saEnd = SaEndCls(self._core, self._cmd_group)
		return self._saEnd

	@property
	def saStart(self):
		"""saStart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_saStart'):
			from .SaStart import SaStartCls
			self._saStart = SaStartCls(self._core, self._cmd_group)
		return self._saStart

	@property
	def speriod(self):
		"""speriod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_speriod'):
			from .Speriod import SperiodCls
			self._speriod = SperiodCls(self._core, self._cmd_group)
		return self._speriod

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'PmchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PmchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SmodulationCls:
	"""Smodulation commands group definition. 7 total commands, 4 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("smodulation", core, parent)

	@property
	def clock(self):
		"""clock commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def ddelay(self):
		"""ddelay commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ddelay'):
			from .Ddelay import DdelayCls
			self._ddelay = DdelayCls(self._core, self._cmd_group)
		return self._ddelay

	@property
	def rcvState(self):
		"""rcvState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rcvState'):
			from .RcvState import RcvStateCls
			self._rcvState = RcvStateCls(self._core, self._cmd_group)
		return self._rcvState

	@property
	def throughput(self):
		"""throughput commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_throughput'):
			from .Throughput import ThroughputCls
			self._throughput = ThroughputCls(self._core, self._cmd_group)
		return self._throughput

	# noinspection PyTypeChecker
	def get_border(self) -> enums.BitOrder:
		"""SCPI: [SOURce<HW>]:BB:DM:SMODulation:BORDer \n
		Snippet: value: enums.BitOrder = driver.source.bb.dm.smodulation.get_border() \n
		Sets the bit order for processing extern serial data. \n
			:return: bit_order: LSBit| MSBit
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DM:SMODulation:BORDer?')
		return Conversions.str_to_scalar_enum(response, enums.BitOrder)

	def set_border(self, bit_order: enums.BitOrder) -> None:
		"""SCPI: [SOURce<HW>]:BB:DM:SMODulation:BORDer \n
		Snippet: driver.source.bb.dm.smodulation.set_border(bit_order = enums.BitOrder.LSBit) \n
		Sets the bit order for processing extern serial data. \n
			:param bit_order: LSBit| MSBit
		"""
		param = Conversions.enum_scalar_to_str(bit_order, enums.BitOrder)
		self._core.io.write(f'SOURce<HwInstance>:BB:DM:SMODulation:BORDer {param}')

	def get_cdt_deviation(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:DM:SMODulation:CDTDeviation \n
		Snippet: value: float = driver.source.bb.dm.smodulation.get_cdt_deviation() \n
		Queries the timing deviations (time offset) between the clock and the data signals. \n
			:return: deviation: float Range: -5E-3 to 5E-3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DM:SMODulation:CDTDeviation?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'SmodulationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SmodulationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LosCls:
	"""Los commands group definition. 12 total commands, 3 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("los", core, parent)

	@property
	def arrival(self):
		"""arrival commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_arrival'):
			from .Arrival import ArrivalCls
			self._arrival = ArrivalCls(self._core, self._cmd_group)
		return self._arrival

	@property
	def departure(self):
		"""departure commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_departure'):
			from .Departure import DepartureCls
			self._departure = DepartureCls(self._core, self._cmd_group)
		return self._departure

	@property
	def random(self):
		"""random commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_random'):
			from .Random import RandomCls
			self._random = RandomCls(self._core, self._cmd_group)
		return self._random

	def get_distance(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:DISTance \n
		Snippet: value: float = driver.source.fsimulator.scm.los.get_distance() \n
		Sets the distance between the base station (BS) and the user terminal (UT) . \n
			:return: los_3_ddistance: float Range: 0 to 1000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:LOS:DISTance?')
		return Conversions.str_to_float(response)

	def set_distance(self, los_3_ddistance: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:DISTance \n
		Snippet: driver.source.fsimulator.scm.los.set_distance(los_3_ddistance = 1.0) \n
		Sets the distance between the base station (BS) and the user terminal (UT) . \n
			:param los_3_ddistance: float Range: 0 to 1000
		"""
		param = Conversions.decimal_value_to_str(los_3_ddistance)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:LOS:DISTance {param}')

	def get_kfactor(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:KFACtor \n
		Snippet: value: float = driver.source.fsimulator.scm.los.get_kfactor() \n
		Sets the ricean K factor. \n
			:return: factor: float Range: -50 to 0
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:LOS:KFACtor?')
		return Conversions.str_to_float(response)

	def set_kfactor(self, factor: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:KFACtor \n
		Snippet: driver.source.fsimulator.scm.los.set_kfactor(factor = 1.0) \n
		Sets the ricean K factor. \n
			:param factor: float Range: -50 to 0
		"""
		param = Conversions.decimal_value_to_str(factor)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:LOS:KFACtor {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:STATe \n
		Snippet: value: bool = driver.source.fsimulator.scm.los.get_state() \n
		Adds a line-of-sight (LOS) component to the cluster. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SCM:LOS:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SCM:LOS:STATe \n
		Snippet: driver.source.fsimulator.scm.los.set_state(state = False) \n
		Adds a line-of-sight (LOS) component to the cluster. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SCM:LOS:STATe {param}')

	def clone(self) -> 'LosCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LosCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class L5BandCls:
	"""L5Band commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("l5Band", core, parent)

	@property
	def b2A(self):
		"""b2A commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_b2A'):
			from .B2A import B2ACls
			self._b2A = B2ACls(self._core, self._cmd_group)
		return self._b2A

	@property
	def b2B(self):
		"""b2B commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_b2B'):
			from .B2B import B2BCls
			self._b2B = B2BCls(self._core, self._cmd_group)
		return self._b2B

	@property
	def b2I(self):
		"""b2I commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_b2I'):
			from .B2I import B2ICls
			self._b2I = B2ICls(self._core, self._cmd_group)
		return self._b2I

	def clone(self) -> 'L5BandCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = L5BandCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AwgnCls:
	"""Awgn commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("awgn", core, parent)

	@property
	def create(self):
		"""create commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_create'):
			from .Create import CreateCls
			self._create = CreateCls(self._core, self._cmd_group)
		return self._create

	def get_samples(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:AWGN:SAMPles \n
		Snippet: value: int = driver.source.bb.arbitrary.tsignal.awgn.get_samples() \n
		Sets the number of samples generated for the AWGN waveform. \n
			:return: par_awgn_samp: integer Range: 1E6 to 1E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:AWGN:SAMPles?')
		return Conversions.str_to_int(response)

	def set_samples(self, par_awgn_samp: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:AWGN:SAMPles \n
		Snippet: driver.source.bb.arbitrary.tsignal.awgn.set_samples(par_awgn_samp = 1) \n
		Sets the number of samples generated for the AWGN waveform. \n
			:param par_awgn_samp: integer Range: 1E6 to 1E9
		"""
		param = Conversions.decimal_value_to_str(par_awgn_samp)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:AWGN:SAMPles {param}')

	def clone(self) -> 'AwgnCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AwgnCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DiqCls:
	"""Diq commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("diq", core, parent)

	@property
	def bbMm1(self):
		"""bbMm1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bbMm1'):
			from .BbMm1 import BbMm1Cls
			self._bbMm1 = BbMm1Cls(self._core, self._cmd_group)
		return self._bbMm1

	@property
	def bbMm2(self):
		"""bbMm2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bbMm2'):
			from .BbMm2 import BbMm2Cls
			self._bbMm2 = BbMm2Cls(self._core, self._cmd_group)
		return self._bbMm2

	def clone(self) -> 'DiqCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DiqCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal.RepeatedCapability import RepeatedCapability
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EchoCls:
	"""Echo commands group definition. 7 total commands, 7 Subgroups, 0 group commands
	Repeated Capability: Echo, default value after init: Echo.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("echo", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_echo_get', 'repcap_echo_set', repcap.Echo.Nr1)

	def repcap_echo_set(self, echo: repcap.Echo) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Echo.Default
		Default value after init: Echo.Nr1"""
		self._cmd_group.set_repcap_enum_value(echo)

	def repcap_echo_get(self) -> repcap.Echo:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def aazimuth(self):
		"""aazimuth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aazimuth'):
			from .Aazimuth import AazimuthCls
			self._aazimuth = AazimuthCls(self._core, self._cmd_group)
		return self._aazimuth

	@property
	def aelevation(self):
		"""aelevation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aelevation'):
			from .Aelevation import AelevationCls
			self._aelevation = AelevationCls(self._core, self._cmd_group)
		return self._aelevation

	@property
	def cpDrift(self):
		"""cpDrift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cpDrift'):
			from .CpDrift import CpDriftCls
			self._cpDrift = CpDriftCls(self._core, self._cmd_group)
		return self._cpDrift

	@property
	def cphase(self):
		"""cphase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cphase'):
			from .Cphase import CphaseCls
			self._cphase = CphaseCls(self._core, self._cmd_group)
		return self._cphase

	@property
	def dshift(self):
		"""dshift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dshift'):
			from .Dshift import DshiftCls
			self._dshift = DshiftCls(self._core, self._cmd_group)
		return self._dshift

	@property
	def icPhase(self):
		"""icPhase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_icPhase'):
			from .IcPhase import IcPhaseCls
			self._icPhase = IcPhaseCls(self._core, self._cmd_group)
		return self._icPhase

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	def clone(self) -> 'EchoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EchoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 16 total commands, 3 Subgroups, 13 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import AddCls
			self._add = AddCls(self._core, self._cmd_group)
		return self._add

	@property
	def change(self):
		"""change commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_change'):
			from .Change import ChangeCls
			self._change = ChangeCls(self._core, self._cmd_group)
		return self._change

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import ExecuteCls
			self._execute = ExecuteCls(self._core, self._cmd_group)
		return self._execute

	def abort(self) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ABORt \n
		Snippet: driver.source.bb.measurement.power.abort() \n
		Stops the current measurement. \n
		"""
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:ABORt')

	def abort_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ABORt \n
		Snippet: driver.source.bb.measurement.power.abort_with_opc() \n
		Stops the current measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce:BB:MEASurement:POWer:ABORt', opc_timeout_ms)

	# noinspection PyTypeChecker
	def get_acquisition(self) -> enums.BbMeasPowAcq:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ACQuisition \n
		Snippet: value: enums.BbMeasPowAcq = driver.source.bb.measurement.power.get_acquisition() \n
		Sets the acquisition method. \n
			:return: acquistion: NOMinal| CONTinuous| GATed| MGATed
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:ACQuisition?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowAcq)

	def set_acquisition(self, acquistion: enums.BbMeasPowAcq) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ACQuisition \n
		Snippet: driver.source.bb.measurement.power.set_acquisition(acquistion = enums.BbMeasPowAcq.CONTinuous) \n
		Sets the acquisition method. \n
			:param acquistion: NOMinal| CONTinuous| GATed| MGATed
		"""
		param = Conversions.enum_scalar_to_str(acquistion, enums.BbMeasPowAcq)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:ACQuisition {param}')

	def delete(self) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DELete \n
		Snippet: driver.source.bb.measurement.power.delete() \n
		Removes the selected measurement from the list. \n
		"""
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:DELete')

	def delete_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DELete \n
		Snippet: driver.source.bb.measurement.power.delete_with_opc() \n
		Removes the selected measurement from the list. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce:BB:MEASurement:POWer:DELete', opc_timeout_ms)

	def get_duration(self) -> float:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DURation \n
		Snippet: value: float = driver.source.bb.measurement.power.get_duration() \n
		Sets the measurement's time of a single measurement. \n
			:return: duration: float Range: 1E-3 to 5400
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DURation \n
		Snippet: driver.source.bb.measurement.power.set_duration(duration = 1.0) \n
		Sets the measurement's time of a single measurement. \n
			:param duration: float Range: 1E-3 to 5400
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:DURation {param}')

	# noinspection PyTypeChecker
	def get_gsource(self) -> enums.BbMeasPowGateSour:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:GSOurce \n
		Snippet: value: enums.BbMeasPowGateSour = driver.source.bb.measurement.power.get_gsource() \n
		Determines the marker signal defining the signal part to be evaluated. The available values depend on the selected
		acquisition ([:SOURce]:BB:MEASurement:POWer:ACQuisition) . \n
			:return: gate_source: NONE| MARK1| MARK2| MARK3| MGATed NONE Default value for nominal and continuous acquisition. MARK1|MARK2|MARK3 Marker signal as defined in the baseband MGATed Reserved for multi gated acquisition
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:GSOurce?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowGateSour)

	def set_gsource(self, gate_source: enums.BbMeasPowGateSour) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:GSOurce \n
		Snippet: driver.source.bb.measurement.power.set_gsource(gate_source = enums.BbMeasPowGateSour.MARK1) \n
		Determines the marker signal defining the signal part to be evaluated. The available values depend on the selected
		acquisition ([:SOURce]:BB:MEASurement:POWer:ACQuisition) . \n
			:param gate_source: NONE| MARK1| MARK2| MARK3| MGATed NONE Default value for nominal and continuous acquisition. MARK1|MARK2|MARK3 Marker signal as defined in the baseband MGATed Reserved for multi gated acquisition
		"""
		param = Conversions.enum_scalar_to_str(gate_source, enums.BbMeasPowGateSour)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:GSOurce {param}')

	def get_index(self) -> int:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:INDex \n
		Snippet: value: int = driver.source.bb.measurement.power.get_index() \n
		Selects the measurement index the subsequent settings apply to, for example changing, starting or removing form the list
		of measurements. \n
			:return: meas_index: integer Range: 1 to dynamic
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:INDex?')
		return Conversions.str_to_int(response)

	def set_index(self, meas_index: int) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:INDex \n
		Snippet: driver.source.bb.measurement.power.set_index(meas_index = 1) \n
		Selects the measurement index the subsequent settings apply to, for example changing, starting or removing form the list
		of measurements. \n
			:param meas_index: integer Range: 1 to dynamic
		"""
		param = Conversions.decimal_value_to_str(meas_index)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:INDex {param}')

	# noinspection PyTypeChecker
	def get_output(self) -> enums.BbMeasPowOutp:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:OUTPut \n
		Snippet: value: enums.BbMeasPowOutp = driver.source.bb.measurement.power.get_output() \n
		Defines the output point the measurement are performed at. \n
			:return: output: RFA| RFB| IQOUT1| IQOUT2| BBMM1| BBMM2
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:OUTPut?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowOutp)

	def set_output(self, output: enums.BbMeasPowOutp) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:OUTPut \n
		Snippet: driver.source.bb.measurement.power.set_output(output = enums.BbMeasPowOutp.BBMM1) \n
		Defines the output point the measurement are performed at. \n
			:param output: RFA| RFB| IQOUT1| IQOUT2| BBMM1| BBMM2
		"""
		param = Conversions.enum_scalar_to_str(output, enums.BbMeasPowOutp)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:OUTPut {param}')

	def get_peak(self) -> List[float]:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:PEAK \n
		Snippet: value: List[float] = driver.source.bb.measurement.power.get_peak() \n
		Queries the peak power of the baseband signal at the measurement point determined with the command
		[:SOURce]:BB:MEASurement:POWer:OUTPut. \n
			:return: peak_power: Peak_SubMes#1,Peak_SubMes#2,... Returns the peak power of the measured signal or if a multi-gated acquisition is used, a string of measured values with one value per performed submeasurement Range: -145 to 30
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:BB:MEASurement:POWer:PEAK?')
		return response

	def get_progress(self) -> float:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:PROGress \n
		Snippet: value: float = driver.source.bb.measurement.power.get_progress() \n
		Queries the status of the initiated measurement. The query returns a value that indicates the task progress in percent. \n
			:return: progress: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:PROGress?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_rmode(self) -> enums.BlerTrigMode:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RMODe \n
		Snippet: value: enums.BlerTrigMode = driver.source.bb.measurement.power.get_rmode() \n
		Determines whether a single or a continuous measurement is executed. \n
			:return: run_mode: SINGle| AUTO
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:RMODe?')
		return Conversions.str_to_scalar_enum(response, enums.BlerTrigMode)

	def set_rmode(self, run_mode: enums.BlerTrigMode) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RMODe \n
		Snippet: driver.source.bb.measurement.power.set_rmode(run_mode = enums.BlerTrigMode.AUTO) \n
		Determines whether a single or a continuous measurement is executed. \n
			:param run_mode: SINGle| AUTO
		"""
		param = Conversions.enum_scalar_to_str(run_mode, enums.BlerTrigMode)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:RMODe {param}')

	def get_rms(self) -> List[float]:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RMS \n
		Snippet: value: List[float] = driver.source.bb.measurement.power.get_rms() \n
		Queries the RMS power of the baseband signal at the measurement point determined with the command
		[:SOURce]:BB:MEASurement:POWer:OUTPut. \n
			:return: rms_power: Power_SubMes#1,Level_SubMes#2,... Returns the power of the measured signal or if a multi-gated acquisition is used, a string of measured values with one value per performed submeasurement Range: -145 to 30
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:BB:MEASurement:POWer:RMS?')
		return response

	def get_rstate(self) -> bool:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RSTate \n
		Snippet: value: bool = driver.source.bb.measurement.power.get_rstate() \n
		Queries the state (running/stopped) of the current measurement. \n
			:return: run_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:RSTate?')
		return Conversions.str_to_bool(response)

	# noinspection PyTypeChecker
	def get_source(self) -> enums.BbMeasPowSour:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:SOURce \n
		Snippet: value: enums.BbMeasPowSour = driver.source.bb.measurement.power.get_source() \n
		Defines the measurement signal source. \n
			:return: source: BBA| BBB| BBC| BBD| BBINA| BBINB| FADINPA| FADINPB| FADINPC| FADINPD| FADOUTA| FADOUTB| FADOUTC| FADOUTD| AWGNA| AWGNB| AWGNC| AWGND| STREAMA| STREAMB| STREAMC| STREAMD
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowSour)

	def set_source(self, source: enums.BbMeasPowSour) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:SOURce \n
		Snippet: driver.source.bb.measurement.power.set_source(source = enums.BbMeasPowSour.AWGNA) \n
		Defines the measurement signal source. \n
			:param source: BBA| BBB| BBC| BBD| BBINA| BBINB| FADINPA| FADINPB| FADINPC| FADINPD| FADOUTA| FADOUTB| FADOUTC| FADOUTD| AWGNA| AWGNB| AWGNC| AWGND| STREAMA| STREAMB| STREAMC| STREAMD
		"""
		param = Conversions.enum_scalar_to_str(source, enums.BbMeasPowSour)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:SOURce {param}')

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DpcchCls:
	"""Dpcch commands group definition. 60 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dpcch", core, parent)

	@property
	def ccode(self):
		"""ccode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccode'):
			from .Ccode import CcodeCls
			self._ccode = CcodeCls(self._core, self._cmd_group)
		return self._ccode

	@property
	def fbi(self):
		"""fbi commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fbi'):
			from .Fbi import FbiCls
			self._fbi = FbiCls(self._core, self._cmd_group)
		return self._fbi

	@property
	def hs(self):
		"""hs commands group. 20 Sub-classes, 0 commands."""
		if not hasattr(self, '_hs'):
			from .Hs import HsCls
			self._hs = HsCls(self._core, self._cmd_group)
		return self._hs

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def sformat(self):
		"""sformat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sformat'):
			from .Sformat import SformatCls
			self._sformat = SformatCls(self._core, self._cmd_group)
		return self._sformat

	@property
	def tfci(self):
		"""tfci commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_tfci'):
			from .Tfci import TfciCls
			self._tfci = TfciCls(self._core, self._cmd_group)
		return self._tfci

	@property
	def toffset(self):
		"""toffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toffset'):
			from .Toffset import ToffsetCls
			self._toffset = ToffsetCls(self._core, self._cmd_group)
		return self._toffset

	@property
	def tpc(self):
		"""tpc commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_tpc'):
			from .Tpc import TpcCls
			self._tpc = TpcCls(self._core, self._cmd_group)
		return self._tpc

	def clone(self) -> 'DpcchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DpcchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SetCls:
	"""Set commands group definition. 8 total commands, 8 Subgroups, 0 group commands
	Repeated Capability: ModCodSet, default value after init: ModCodSet.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("set", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_modCodSet_get', 'repcap_modCodSet_set', repcap.ModCodSet.Nr1)

	def repcap_modCodSet_set(self, modCodSet: repcap.ModCodSet) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to ModCodSet.Default
		Default value after init: ModCodSet.Nr1"""
		self._cmd_group.set_repcap_enum_value(modCodSet)

	def repcap_modCodSet_get(self) -> repcap.ModCodSet:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def adfl(self):
		"""adfl commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adfl'):
			from .Adfl import AdflCls
			self._adfl = AdflCls(self._core, self._cmd_group)
		return self._adfl

	@property
	def ctype(self):
		"""ctype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctype'):
			from .Ctype import CtypeCls
			self._ctype = CtypeCls(self._core, self._cmd_group)
		return self._ctype

	@property
	def dfl(self):
		"""dfl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfl'):
			from .Dfl import DflCls
			self._dfl = DflCls(self._core, self._cmd_group)
		return self._dfl

	@property
	def frames(self):
		"""frames commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frames'):
			from .Frames import FramesCls
			self._frames = FramesCls(self._core, self._cmd_group)
		return self._frames

	@property
	def mcod(self):
		"""mcod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcod'):
			from .Mcod import McodCls
			self._mcod = McodCls(self._core, self._cmd_group)
		return self._mcod

	@property
	def pcod(self):
		"""pcod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcod'):
			from .Pcod import PcodCls
			self._pcod = PcodCls(self._core, self._cmd_group)
		return self._pcod

	@property
	def pstate(self):
		"""pstate commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pstate'):
			from .Pstate import PstateCls
			self._pstate = PstateCls(self._core, self._cmd_group)
		return self._pstate

	@property
	def sfactor(self):
		"""sfactor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfactor'):
			from .Sfactor import SfactorCls
			self._sfactor = SfactorCls(self._core, self._cmd_group)
		return self._sfactor

	def clone(self) -> 'SetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EdchCls:
	"""Edch commands group definition. 5 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("edch", core, parent)

	@property
	def repeat(self):
		"""repeat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_repeat'):
			from .Repeat import RepeatCls
			self._repeat = RepeatCls(self._core, self._cmd_group)
		return self._repeat

	@property
	def row(self):
		"""row commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_row'):
			from .Row import RowCls
			self._row = RowCls(self._core, self._cmd_group)
		return self._row

	@property
	def rowCount(self):
		"""rowCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rowCount'):
			from .RowCount import RowCountCls
			self._rowCount = RowCountCls(self._core, self._cmd_group)
		return self._rowCount

	@property
	def ttiedch(self):
		"""ttiedch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttiedch'):
			from .Ttiedch import TtiedchCls
			self._ttiedch = TtiedchCls(self._core, self._cmd_group)
		return self._ttiedch

	def clone(self) -> 'EdchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EdchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtciCls:
	"""Rtci commands group definition. 25 total commands, 3 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rtci", core, parent)

	@property
	def wave(self):
		"""wave commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_wave'):
			from .Wave import WaveCls
			self._wave = WaveCls(self._core, self._cmd_group)
		return self._wave

	@property
	def wlist(self):
		"""wlist commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_wlist'):
			from .Wlist import WlistCls
			self._wlist = WlistCls(self._core, self._cmd_group)
		return self._wlist

	@property
	def sequencer(self):
		"""sequencer commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_sequencer'):
			from .Sequencer import SequencerCls
			self._sequencer = SequencerCls(self._core, self._cmd_group)
		return self._sequencer

	# noinspection PyTypeChecker
	def get_pdw_format(self) -> enums.ExtSeqPdwVariant:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:PDWFormat \n
		Snippet: value: enums.ExtSeqPdwVariant = driver.source.bb.esequencer.rtci.get_pdw_format() \n
		Selects the PDW format. \n
			:return: format_py: BASic| EXPert
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ESEQuencer:RTCI:PDWFormat?')
		return Conversions.str_to_scalar_enum(response, enums.ExtSeqPdwVariant)

	def set_pdw_format(self, format_py: enums.ExtSeqPdwVariant) -> None:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:PDWFormat \n
		Snippet: driver.source.bb.esequencer.rtci.set_pdw_format(format_py = enums.ExtSeqPdwVariant.BASic) \n
		Selects the PDW format. \n
			:param format_py: BASic| EXPert
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.ExtSeqPdwVariant)
		self._core.io.write(f'SOURce<HwInstance>:BB:ESEQuencer:RTCI:PDWFormat {param}')

	# noinspection PyTypeChecker
	def get_pdw_rate(self) -> enums.ExtSeqPdwRateMode:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:PDWRate \n
		Snippet: value: enums.ExtSeqPdwRateMode = driver.source.bb.esequencer.rtci.get_pdw_rate() \n
		No command help available \n
			:return: rate_mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ESEQuencer:RTCI:PDWRate?')
		return Conversions.str_to_scalar_enum(response, enums.ExtSeqPdwRateMode)

	def set_pdw_rate(self, rate_mode: enums.ExtSeqPdwRateMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:PDWRate \n
		Snippet: driver.source.bb.esequencer.rtci.set_pdw_rate(rate_mode = enums.ExtSeqPdwRateMode.HSPeed) \n
		No command help available \n
			:param rate_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(rate_mode, enums.ExtSeqPdwRateMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ESEQuencer:RTCI:PDWRate {param}')

	def clone(self) -> 'RtciCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RtciCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SweepCls:
	"""Sweep commands group definition. 27 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sweep", core, parent)

	@property
	def combined(self):
		"""combined commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_combined'):
			from .Combined import CombinedCls
			self._combined = CombinedCls(self._core, self._cmd_group)
		return self._combined

	@property
	def power(self):
		"""power commands group. 3 Sub-classes, 7 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def frequency(self):
		"""frequency commands group. 2 Sub-classes, 7 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	def reset_all(self) -> None:
		"""SCPI: [SOURce<HW>]:SWEep:RESet:[ALL] \n
		Snippet: driver.source.sweep.reset_all() \n
		Resets all active sweeps to the starting point. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:SWEep:RESet:ALL')

	def reset_all_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:SWEep:RESet:[ALL] \n
		Snippet: driver.source.sweep.reset_all_with_opc() \n
		Resets all active sweeps to the starting point. \n
		Same as reset_all, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:SWEep:RESet:ALL', opc_timeout_ms)

	def clone(self) -> 'SweepCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SweepCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PatternCls:
	"""Pattern commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pattern", core, parent)

	def set(self, pattern: List[str], bitcount: int, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:DATA:PATTern \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.data.pattern.set(pattern = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1, baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Sets the bit pattern for the PATTern selection. The first parameter determines the bit pattern (choice of hexadecimal,
		octal or binary notation) , the second specifies the number of bits to use. For the traffic channels, this value is
		specific for the selected radio configuration. \n
			:param pattern: numeric
			:param bitcount: integer Range: 1 to 64
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('pattern', pattern, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:DATA:PATTern {param}'.rstrip())

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Response structure. Fields: \n
			- Pattern: List[str]: numeric
			- Bitcount: int: integer Range: 1 to 64"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:DATA:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.c2K.bstation.cgroup.coffset.data.pattern.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Sets the bit pattern for the PATTern selection. The first parameter determines the bit pattern (choice of hexadecimal,
		octal or binary notation) , the second specifies the number of bits to use. For the traffic channels, this value is
		specific for the selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: structure: for return value, see the help for PatternStruct structure arguments."""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:DATA:PATTern?', self.__class__.PatternStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def dpattern(self):
		"""dpattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dpattern'):
			from .Dpattern import DpatternCls
			self._dpattern = DpatternCls(self._core, self._cmd_group)
		return self._dpattern

	def get_dselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DSELection \n
		Snippet: value: str = driver.source.bb.btooth.econfiguration.pconfiguration.data.get_dselection() \n
		Specifies data list file. The setting is relevant for [:SOURce<hw>]:BB:BTOoth:ECONfiguration:PCONfiguration:DATADLISt \n
			:return: dselection: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DSELection?')
		return trim_str_response(response)

	def set_dselection(self, dselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DSELection \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.data.set_dselection(dselection = 'abc') \n
		Specifies data list file. The setting is relevant for [:SOURce<hw>]:BB:BTOoth:ECONfiguration:PCONfiguration:DATADLISt \n
			:param dselection: string
		"""
		param = Conversions.value_to_quoted_str(dselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DSELection {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.DataSourceB:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA \n
		Snippet: value: enums.DataSourceB = driver.source.bb.btooth.econfiguration.pconfiguration.data.get_value() \n
		Selects the pattern source used for the payload. \n
			:return: data: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt ALL0 / ALL1 All 0 or all 1 pattern PATTern User-defined pattern. The pattern can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DPATtern PNxx Pseudo-random bit sequences (PRBS) of a length of xx bits. The length in bit can be 9, 11, 15, 16, 20, 21, or 23. DLISt Internal data list is used. The data list can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DSELection
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceB)

	def set_value(self, data: enums.DataSourceB) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.data.set_value(data = enums.DataSourceB.ALL0) \n
		Selects the pattern source used for the payload. \n
			:param data: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt ALL0 / ALL1 All 0 or all 1 pattern PATTern User-defined pattern. The pattern can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DPATtern PNxx Pseudo-random bit sequences (PRBS) of a length of xx bits. The length in bit can be 9, 11, 15, 16, 20, 21, or 23. DLISt Internal data list is used. The data list can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:DATA:DSELection
		"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceB)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:DATA {param}')

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import enums
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UsageCls:
	"""Usage commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("usage", core, parent)

	def set(self, srs_rs_set_usage: enums.SrsRsSetUsageAll, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, resourceSetNull=repcap.ResourceSetNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:SRS:RS:SET<GR0>:USAGe \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.srs.rs.set.usage.set(srs_rs_set_usage = enums.SrsRsSetUsageAll.ASW, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, resourceSetNull = repcap.ResourceSetNull.Default) \n
		Queries the type of the SRS transmission. \n
			:param srs_rs_set_usage: ASW| BM| CB| NCB NCB = non-codebook based CB = codebook BM = beam management (reserved for futute use) ASW = antenna switching (reserved for futute use)
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param resourceSetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Set')
		"""
		param = Conversions.enum_scalar_to_str(srs_rs_set_usage, enums.SrsRsSetUsageAll)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		resourceSetNull_cmd_val = self._cmd_group.get_repcap_cmd_value(resourceSetNull, repcap.ResourceSetNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:SRS:RS:SET{resourceSetNull_cmd_val}:USAGe {param}')

	# noinspection PyTypeChecker
	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, resourceSetNull=repcap.ResourceSetNull.Default) -> enums.SrsRsSetUsageAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:SRS:RS:SET<GR0>:USAGe \n
		Snippet: value: enums.SrsRsSetUsageAll = driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.srs.rs.set.usage.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, resourceSetNull = repcap.ResourceSetNull.Default) \n
		Queries the type of the SRS transmission. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param resourceSetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Set')
			:return: srs_rs_set_usage: ASW| BM| CB| NCB NCB = non-codebook based CB = codebook BM = beam management (reserved for futute use) ASW = antenna switching (reserved for futute use)"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		resourceSetNull_cmd_val = self._cmd_group.get_repcap_cmd_value(resourceSetNull, repcap.ResourceSetNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:SRS:RS:SET{resourceSetNull_cmd_val}:USAGe?')
		return Conversions.str_to_scalar_enum(response, enums.SrsRsSetUsageAll)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TxCls:
	"""Tx commands group definition. 116 total commands, 29 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tx", core, parent)

	@property
	def ac(self):
		"""ac commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ac'):
			from .Ac import AcCls
			self._ac = AcCls(self._core, self._cmd_group)
		return self._ac

	@property
	def ad(self):
		"""ad commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ad'):
			from .Ad import AdCls
			self._ad = AdCls(self._core, self._cmd_group)
		return self._ad

	@property
	def ae(self):
		"""ae commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ae'):
			from .Ae import AeCls
			self._ae = AeCls(self._core, self._cmd_group)
		return self._ae

	@property
	def af(self):
		"""af commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_af'):
			from .Af import AfCls
			self._af = AfCls(self._core, self._cmd_group)
		return self._af

	@property
	def ag(self):
		"""ag commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ag'):
			from .Ag import AgCls
			self._ag = AgCls(self._core, self._cmd_group)
		return self._ag

	@property
	def ah(self):
		"""ah commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ah'):
			from .Ah import AhCls
			self._ah = AhCls(self._core, self._cmd_group)
		return self._ah

	@property
	def bc(self):
		"""bc commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bc'):
			from .Bc import BcCls
			self._bc = BcCls(self._core, self._cmd_group)
		return self._bc

	@property
	def bd(self):
		"""bd commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bd'):
			from .Bd import BdCls
			self._bd = BdCls(self._core, self._cmd_group)
		return self._bd

	@property
	def be(self):
		"""be commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_be'):
			from .Be import BeCls
			self._be = BeCls(self._core, self._cmd_group)
		return self._be

	@property
	def bf(self):
		"""bf commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bf'):
			from .Bf import BfCls
			self._bf = BfCls(self._core, self._cmd_group)
		return self._bf

	@property
	def bg(self):
		"""bg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bg'):
			from .Bg import BgCls
			self._bg = BgCls(self._core, self._cmd_group)
		return self._bg

	@property
	def bh(self):
		"""bh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bh'):
			from .Bh import BhCls
			self._bh = BhCls(self._core, self._cmd_group)
		return self._bh

	@property
	def cd(self):
		"""cd commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_cd'):
			from .Cd import CdCls
			self._cd = CdCls(self._core, self._cmd_group)
		return self._cd

	@property
	def ce(self):
		"""ce commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ce'):
			from .Ce import CeCls
			self._ce = CeCls(self._core, self._cmd_group)
		return self._ce

	@property
	def cf(self):
		"""cf commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_cf'):
			from .Cf import CfCls
			self._cf = CfCls(self._core, self._cmd_group)
		return self._cf

	@property
	def cg(self):
		"""cg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_cg'):
			from .Cg import CgCls
			self._cg = CgCls(self._core, self._cmd_group)
		return self._cg

	@property
	def ch(self):
		"""ch commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ch'):
			from .Ch import ChCls
			self._ch = ChCls(self._core, self._cmd_group)
		return self._ch

	@property
	def de(self):
		"""de commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_de'):
			from .De import DeCls
			self._de = DeCls(self._core, self._cmd_group)
		return self._de

	@property
	def df(self):
		"""df commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_df'):
			from .Df import DfCls
			self._df = DfCls(self._core, self._cmd_group)
		return self._df

	@property
	def dg(self):
		"""dg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_dg'):
			from .Dg import DgCls
			self._dg = DgCls(self._core, self._cmd_group)
		return self._dg

	@property
	def dh(self):
		"""dh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_dh'):
			from .Dh import DhCls
			self._dh = DhCls(self._core, self._cmd_group)
		return self._dh

	@property
	def ef(self):
		"""ef commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ef'):
			from .Ef import EfCls
			self._ef = EfCls(self._core, self._cmd_group)
		return self._ef

	@property
	def eg(self):
		"""eg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_eg'):
			from .Eg import EgCls
			self._eg = EgCls(self._core, self._cmd_group)
		return self._eg

	@property
	def eh(self):
		"""eh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_eh'):
			from .Eh import EhCls
			self._eh = EhCls(self._core, self._cmd_group)
		return self._eh

	@property
	def fg(self):
		"""fg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_fg'):
			from .Fg import FgCls
			self._fg = FgCls(self._core, self._cmd_group)
		return self._fg

	@property
	def fh(self):
		"""fh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_fh'):
			from .Fh import FhCls
			self._fh = FhCls(self._core, self._cmd_group)
		return self._fh

	@property
	def gh(self):
		"""gh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_gh'):
			from .Gh import GhCls
			self._gh = GhCls(self._core, self._cmd_group)
		return self._gh

	@property
	def row(self):
		"""row commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_row'):
			from .Row import RowCls
			self._row = RowCls(self._core, self._cmd_group)
		return self._row

	@property
	def ab(self):
		"""ab commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ab'):
			from .Ab import AbCls
			self._ab = AbCls(self._core, self._cmd_group)
		return self._ab

	def clone(self) -> 'TxCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TxCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConflictCls:
	"""Conflict commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("conflict", core, parent)

	def get(self, cellNull=repcap.CellNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:TXBW:CONFlict \n
		Snippet: value: bool = driver.source.bb.nr5G.node.cell.txbw.conflict.get(cellNull = repcap.CellNull.Default) \n
		Queries whether there is a conflict. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: conflict: 1| ON| 0| OFF"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:TXBW:CONFlict?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CoffsetCls:
	"""Coffset commands group definition. 31 total commands, 13 Subgroups, 0 group commands
	Repeated Capability: Offset, default value after init: Offset.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coffset", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_offset_get', 'repcap_offset_set', repcap.Offset.Nr1)

	def repcap_offset_set(self, offset: repcap.Offset) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Offset.Default
		Default value after init: Offset.Nr1"""
		self._cmd_group.set_repcap_enum_value(offset)

	def repcap_offset_get(self) -> repcap.Offset:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def ccoding(self):
		"""ccoding commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import CcodingCls
			self._ccoding = CcodingCls(self._core, self._cmd_group)
		return self._ccoding

	@property
	def data(self):
		"""data commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def derror(self):
		"""derror commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_derror'):
			from .Derror import DerrorCls
			self._derror = DerrorCls(self._core, self._cmd_group)
		return self._derror

	@property
	def flength(self):
		"""flength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_flength'):
			from .Flength import FlengthCls
			self._flength = FlengthCls(self._core, self._cmd_group)
		return self._flength

	@property
	def lcMask(self):
		"""lcMask commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lcMask'):
			from .LcMask import LcMaskCls
			self._lcMask = LcMaskCls(self._core, self._cmd_group)
		return self._lcMask

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def qwCode(self):
		"""qwCode commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_qwCode'):
			from .QwCode import QwCodeCls
			self._qwCode = QwCodeCls(self._core, self._cmd_group)
		return self._qwCode

	@property
	def realtime(self):
		"""realtime commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_realtime'):
			from .Realtime import RealtimeCls
			self._realtime = RealtimeCls(self._core, self._cmd_group)
		return self._realtime

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def tpc(self):
		"""tpc commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_tpc'):
			from .Tpc import TpcCls
			self._tpc = TpcCls(self._core, self._cmd_group)
		return self._tpc

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def wcode(self):
		"""wcode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_wcode'):
			from .Wcode import WcodeCls
			self._wcode = WcodeCls(self._core, self._cmd_group)
		return self._wcode

	@property
	def wlength(self):
		"""wlength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_wlength'):
			from .Wlength import WlengthCls
			self._wlength = WlengthCls(self._core, self._cmd_group)
		return self._wlength

	def clone(self) -> 'CoffsetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CoffsetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NmOffsetCls:
	"""NmOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nmOffset", core, parent)

	def set(self, num_min_app_offset: int, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:MAOFfset:NMOFfset \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.maOffset.nmOffset.set(num_min_app_offset = 1, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Turns the 'Minimum Applicable Offset Indicator' field in DCI format 1_1 on and off and defines the number of K0 values
		you can configure. \n
			:param num_min_app_offset: integer Range: 0 to 16
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
		"""
		param = Conversions.decimal_value_to_str(num_min_app_offset)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:MAOFfset:NMOFfset {param}')

	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:MAOFfset:NMOFfset \n
		Snippet: value: int = driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.maOffset.nmOffset.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Turns the 'Minimum Applicable Offset Indicator' field in DCI format 1_1 on and off and defines the number of K0 values
		you can configure. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: num_min_app_offset: No help available"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:MAOFfset:NMOFfset?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PucchCls:
	"""Pucch commands group definition. 8 total commands, 0 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pucch", core, parent)

	def get_de_shift(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:DESHift \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_de_shift() \n
		No command help available \n
			:return: delta_shift: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:DESHift?')
		return Conversions.str_to_int(response)

	def set_de_shift(self, delta_shift: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:DESHift \n
		Snippet: driver.source.bb.v5G.uplink.pucch.set_de_shift(delta_shift = 1) \n
		No command help available \n
			:param delta_shift: No help available
		"""
		param = Conversions.decimal_value_to_str(delta_shift)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUCCh:DESHift {param}')

	def get_n_1_cs(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N1CS \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_n_1_cs() \n
		No command help available \n
			:return: n_1_cs: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:N1CS?')
		return Conversions.str_to_int(response)

	def set_n_1_cs(self, n_1_cs: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N1CS \n
		Snippet: driver.source.bb.v5G.uplink.pucch.set_n_1_cs(n_1_cs = 1) \n
		No command help available \n
			:param n_1_cs: No help available
		"""
		param = Conversions.decimal_value_to_str(n_1_cs)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUCCh:N1CS {param}')

	def get_n_1_e_max(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N1EMax \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_n_1_e_max() \n
		No command help available \n
			:return: n_1_e_max: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:N1EMax?')
		return Conversions.str_to_int(response)

	def get_n_1_n_max(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N1NMax \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_n_1_n_max() \n
		No command help available \n
			:return: n_1_norm_cp: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:N1NMax?')
		return Conversions.str_to_int(response)

	def get_n_2_max(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N2Max \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_n_2_max() \n
		No command help available \n
			:return: n_2_max: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:N2Max?')
		return Conversions.str_to_int(response)

	def get_n_2_rb(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N2RB \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_n_2_rb() \n
		No command help available \n
			:return: n_2_rb: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:N2RB?')
		return Conversions.str_to_int(response)

	def set_n_2_rb(self, n_2_rb: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N2RB \n
		Snippet: driver.source.bb.v5G.uplink.pucch.set_n_2_rb(n_2_rb = 1) \n
		No command help available \n
			:param n_2_rb: No help available
		"""
		param = Conversions.decimal_value_to_str(n_2_rb)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUCCh:N2RB {param}')

	def get_n_3_max(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:N3Max \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_n_3_max() \n
		No command help available \n
			:return: n_3_max: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:N3Max?')
		return Conversions.str_to_int(response)

	def get_no_rb(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:NORB \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pucch.get_no_rb() \n
		No command help available \n
			:return: rb_count: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUCCh:NORB?')
		return Conversions.str_to_int(response)

	def set_no_rb(self, rb_count: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUCCh:NORB \n
		Snippet: driver.source.bb.v5G.uplink.pucch.set_no_rb(rb_count = 1) \n
		No command help available \n
			:param rb_count: No help available
		"""
		param = Conversions.decimal_value_to_str(rb_count)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUCCh:NORB {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SignalsCls:
	"""Signals commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("signals", core, parent)

	def get(self, stream=repcap.Stream.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:[STReam<CH>]:SBAS:ACTive:SIGNals \n
		Snippet: value: str = driver.source.bb.gnss.rt.stream.sbas.active.signals.get(stream = repcap.Stream.Default) \n
		Queries active signals of a GNSS in a comma-separated list. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:return: active_signals: string"""
		stream_cmd_val = self._cmd_group.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RT:STReam{stream_cmd_val}:SBAS:ACTive:SIGNals?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CdStateCls:
	"""CdState commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cdState", core, parent)

	def set(self, csi_rs_state: bool, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:DRS:CELL<CH0>:CDSTate \n
		Snippet: driver.source.bb.v5G.downlink.drs.cell.cdState.set(csi_rs_state = False, cellNull = repcap.CellNull.Default) \n
		No command help available \n
			:param csi_rs_state: No help available
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.bool_to_str(csi_rs_state)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:DRS:CELL{cellNull_cmd_val}:CDSTate {param}')

	def get(self, cellNull=repcap.CellNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:DRS:CELL<CH0>:CDSTate \n
		Snippet: value: bool = driver.source.bb.v5G.downlink.drs.cell.cdState.get(cellNull = repcap.CellNull.Default) \n
		No command help available \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: csi_rs_state: No help available"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:DRS:CELL{cellNull_cmd_val}:CDSTate?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrachCls:
	"""Prach commands group definition. 12 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prach", core, parent)

	@property
	def cframes(self):
		"""cframes commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cframes'):
			from .Cframes import CframesCls
			self._cframes = CframesCls(self._core, self._cmd_group)
		return self._cframes

	@property
	def prFormat(self):
		"""prFormat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prFormat'):
			from .PrFormat import PrFormatCls
			self._prFormat = PrFormatCls(self._core, self._cmd_group)
		return self._prFormat

	@property
	def prState(self):
		"""prState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prState'):
			from .PrState import PrStateCls
			self._prState = PrStateCls(self._core, self._cmd_group)
		return self._prState

	@property
	def prtt(self):
		"""prtt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prtt'):
			from .Prtt import PrttCls
			self._prtt = PrttCls(self._core, self._cmd_group)
		return self._prtt

	@property
	def subf(self):
		"""subf commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_subf'):
			from .Subf import SubfCls
			self._subf = SubfCls(self._core, self._cmd_group)
		return self._subf

	def clone(self) -> 'PrachCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PrachCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.Utilities import trim_str_response
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RvSequenceCls:
	"""RvSequence commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rvSequence", core, parent)

	def set(self, rv_sequence: str, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:ENH:DCH:HSUPA:RVSequence \n
		Snippet: driver.source.bb.tdscdma.down.cell.enh.dch.hsupa.rvSequence.set(rv_sequence = 'abc', cell = repcap.Cell.Default) \n
		For HARQ mode set to constant NACK, sets the retransmission sequence. For HSUPA, the command is a query only. \n
			:param rv_sequence: string of 30 coma-separated values The sequence length determines the maximum number of retransmissions. New data is retrieved from the data source after reaching the end of the sequence.
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
		"""
		param = Conversions.value_to_quoted_str(rv_sequence)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:ENH:DCH:HSUPA:RVSequence {param}')

	def get(self, cell=repcap.Cell.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:ENH:DCH:HSUPA:RVSequence \n
		Snippet: value: str = driver.source.bb.tdscdma.down.cell.enh.dch.hsupa.rvSequence.get(cell = repcap.Cell.Default) \n
		For HARQ mode set to constant NACK, sets the retransmission sequence. For HSUPA, the command is a query only. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: rv_sequence: string of 30 coma-separated values The sequence length determines the maximum number of retransmissions. New data is retrieved from the data source after reaching the end of the sequence."""
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:ENH:DCH:HSUPA:RVSequence?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CorrelationCls:
	"""Correlation commands group definition. 232 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("correlation", core, parent)

	@property
	def rx(self):
		"""rx commands group. 29 Sub-classes, 0 commands."""
		if not hasattr(self, '_rx'):
			from .Rx import RxCls
			self._rx = RxCls(self._core, self._cmd_group)
		return self._rx

	@property
	def tx(self):
		"""tx commands group. 29 Sub-classes, 0 commands."""
		if not hasattr(self, '_tx'):
			from .Tx import TxCls
			self._tx = TxCls(self._core, self._cmd_group)
		return self._tx

	def clone(self) -> 'CorrelationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CorrelationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NoLayersCls:
	"""NoLayers commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("noLayers", core, parent)

	def get(self, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:ALLoc<CH0>:PRECoding:NOLayers \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.alloc.precoding.noLayers.get(allocationNull = repcap.AllocationNull.Default) \n
		Queries the number of layers for the selected allocation. \n
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: prec_lay_cnt: integer Range: 1 to 2"""
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:ALLoc{allocationNull_cmd_val}:PRECoding:NOLayers?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlistCls:
	"""Slist commands group definition. 7 total commands, 3 Subgroups, 3 group commands
	Repeated Capability: Index, default value after init: Index.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slist", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_index_get', 'repcap_index_set', repcap.Index.Nr1)

	def repcap_index_set(self, index: repcap.Index) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Index.Default
		Default value after init: Index.Nr1"""
		self._cmd_group.set_repcap_enum_value(index)

	def repcap_index_get(self) -> repcap.Index:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def ports(self):
		"""ports commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ports'):
			from .Ports import PortsCls
			self._ports = PortsCls(self._core, self._cmd_group)
		return self._ports

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def get_catalog(self) -> str:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:CATalog \n
		Snippet: value: str = driver.source.correction.fresponse.rf.user.slist.get_catalog() \n
		Queries the S-parameter files included in the current S-paramters list. \n
			:return: catalog: filename1,filename2,...filename10 Returns a string of filenames separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:CATalog?')
		return trim_str_response(response)

	def clear(self) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:CLEar \n
		Snippet: driver.source.correction.fresponse.rf.user.slist.clear() \n
		Deletes all entries in the lists. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:CLEar \n
		Snippet: driver.source.correction.fresponse.rf.user.slist.clear_with_opc() \n
		Deletes all entries in the lists. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:CLEar', opc_timeout_ms)

	def get_size(self) -> int:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:SIZE \n
		Snippet: value: int = driver.source.correction.fresponse.rf.user.slist.get_size() \n
		Queries the number of files in the list. \n
			:return: freq_resp_rf_sli_si: integer Range: 0 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:SIZE?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'SlistCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SlistCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdidCls:
	"""Adid commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("adid", core, parent)

	def set(self, adid: List[str], bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ADID \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.adid.set(adid = ['rawAbc1', 'rawAbc2', 'rawAbc3'], bitcount = 1) \n
		Specifies 'Advertising Data ID' in hexadecimal format to be signaled within an extended header. \n
			:param adid: numeric
			:param bitcount: integer Range: 12 to 12
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('adid', adid, DataType.RawStringList, None), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ADID {param}'.rstrip())

	# noinspection PyTypeChecker
	class AdidStruct(StructBase):
		"""Response structure. Fields: \n
			- Adid: List[str]: numeric
			- Bitcount: int: integer Range: 12 to 12"""
		__meta_args_list = [
			ArgStruct('Adid', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Adid: List[str] = None
			self.Bitcount: int = None

	def get(self) -> AdidStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ADID \n
		Snippet: value: AdidStruct = driver.source.bb.btooth.econfiguration.pconfiguration.adid.get() \n
		Specifies 'Advertising Data ID' in hexadecimal format to be signaled within an extended header. \n
			:return: structure: for return value, see the help for AdidStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ADID?', self.__class__.AdidStruct())
